#
# spec file for package libksi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 13
Name:           libksi
Version:        3.21.3087
Release:        1.1
Summary:        GuardTime KSI API
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/guardtime/libksi/archive/refs/tags/v%{version}.tar.gz
Source:         %{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  curl-devel
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
LibKSI - Keyless Signature Infrastructure GuardTime client library

%package -n %{name}%{sover}
Summary:        GuardTime KSI API
Group:          System/Libraries

%description -n %{name}%{sover}
LibKSI - Keyless Signature Infrastructure GuardTime client library

%package devel
Summary:        Development files for the %{name} package
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
LibKSI - Keyless Signature Infrastructure GuardTime client library
The libksi-devel package contains the header files and libraries
needed to develop applications using libksi.

%prep
%autosetup -p1
autoreconf -ifv

%build
%configure \
	--disable-static \
	--with-cafile=%{_sysconfdir}/ssl/ca-bundle.pem
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print
rm -v %{buildroot}/%{_datadir}/doc/%{name}/license.txt
rm -v %{buildroot}/%{_datadir}/doc/%{name}/changelog

%check
#make check
#make test

%post -n %{name}%{sover} -p /sbin/ldconfig

%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%defattr(-,root,root)
%doc license.txt changelog
%{_libdir}/libksi.so.*

%files devel
%defattr(-,root,root)
%doc license.txt changelog doc/
%{_includedir}/ksi
%{_libdir}/libksi.so
%{_libdir}/pkgconfig/libksi.pc

%changelog
* Tue Nov  5 2024 Thomas Blume <Thomas.Blume@suse.com>
- update to libksi 3.21.3087
- switched from unmaintained old source repo to current:
  https://github.com/guardtime/libksi
- removed patches: libksi-build-with-openssl-1.1.0.patch
- see /usr/share/doc/packages/libksi13/changelog for details
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Aug 22 2017 pmonrealgonzalez@suse.com
- Fixed errors when building with openssl-1.1.0 [bsc#1042656]
  * Added patch libksi-build-with-openssl-1.1.0.patch
* Wed Feb 15 2017 ndas@suse.de
- This library is needed for latest rsyslog 8.24.0(fate#320546)
* Sat Jan  2 2016 astieger@suse.com
- libksi 3.4.0.5 (1:0:0)
  * Removed all default endpoints.
  * Added multi signature container.
  * Publications file parsing and verification are now more strict.
  * Publications file verification customizable.
  * Added fast tlv parser.
  * Fixed getLatestPublication and getNearestPublication.
  * Restructured logging (new log levels).
  * All size variables changed to size_t.
  * Hash algorithm id changed from int to KSI_HashAlgorithm.
  * Publications file creation and signing support.
  * Hashing algorithm RIPEMD-256 removed.
  * Local aggregation support.
  * Fixed calendar hash chain calculation.
* Fri Jul  3 2015 astieger@suse.com
- correct license header of rest/resigner.c (as sent by copyright
  holder in https://github.com/rgerhards/libksi/pull/1)
* Thu Jul  2 2015 astieger@suse.com
- import and adjust from adiscon src rpm for SUSE
* Fri Jun 26 2015 friedl@adiscon.com
- Created initial RPM for libksi!
